@@ -3,14 +3,16 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play a MIDI score in real-time
 
-our $VERSION = '0.0109';
+our $VERSION = '0.0110';
 
 use strict;
 use warnings;
 
+use File::Basename qw(fileparse);
 use MIDI::RtMidi::FFI::Device ();
 use MIDI::Util qw(get_microseconds score2events);
-use Time::HiRes qw(usleep);
+use Path::Tiny qw(path);
+use Time::HiRes qw(time usleep);
 
 
 sub new {
@@ -24,6 +26,11 @@ sub new {
     $opts{sleep}    //= 1;
     $opts{loop}     ||= 1;
     $opts{infinite} //= 1;
+    $opts{verbose}  //= 1;
+    $opts{deposit}  ||= '';
+    if ($opts{deposit}) {
+        ($opts{prefix}, $opts{path}) = fileparse($opts{deposit});
+    }
 
     $opts{device} = RtMidiOut->new;
 
@@ -58,13 +65,17 @@ sub _play {
     for my $event (@$events) {
         next if $event->[0] =~ /set_tempo|time_signature/;
         if ( $event->[0] eq 'text_event' ) {
-            printf "%s\n", $event->[-1];
+            printf "%s\n", $event->[-1] if $self->{verbose};
             next;
         }
         my $useconds = $micros * $event->[1];
         usleep($useconds) if $useconds > 0 && $useconds < 1_000_000;
         $self->{device}->send_event( $event->[0] => @{ $event }[ 2 .. $#$event ] );
     }
+    if ($self->{deposit}) {
+        my $filename = path($self->{path}, $self->{prefix} . time() . '.midi');
+        $self->{score}->write_score("$filename");
+    }
     sleep($self->{sleep});
     $self->_reset_score;
 }
@@ -107,7 +118,7 @@ MIDI::RtMidi::ScorePlayer - Play a MIDI score in real-time
 
 =head1 VERSION
 
-version 0.0109
+version 0.0110
 
 =head1 SYNOPSIS
 
@@ -143,6 +154,8 @@ version 0.0109
       sleep    => 2, # number of seconds to sleep between loops (default: 1)
       loop     => 4, # loop limit if finite (default: 1)
       infinite => 0, # loop infinitely (default: 1)
+      deposit  => 'path/prefix-', # optionally make a file after each loop
+			vebose   => 0, # show our progress (default: 1)
   )->play;
 
 =head1 DESCRIPTION
@@ -158,10 +171,8 @@ L<MIDI::Simple>.
 
 Besides being handed the B<common> arguments, each B<part> function
 gets a handy, increasing B<_part> number, starting at one, which can
-be used in the part functions.
-
-These parts are synch'd together, given the B<new> parameters that are
-described in the example above.
+be used in the part functions. These parts are synch'd together, given
+the B<new> parameters that are described in the example above.
 
 =head2 Hints
 
